[−][src]Struct enumflags::BitFlags
Methods
impl<T> BitFlags<T> where
T: RawBitFlags, [src]
T: RawBitFlags,
pub unsafe fn new(val: T::Type) -> Self[src]
Create a new BitFlags unsafely. Consider using from_bits or from_bits_truncate.
impl<T> BitFlags<T> where
T: RawBitFlags, [src]
T: RawBitFlags,
pub fn empty() -> Self[src]
Create an empty BitFlags. Empty means 0.
pub fn all() -> Self[src]
Sets all flags.
pub fn is_all(self) -> bool[src]
Returns true if all flags are set
pub fn is_empty(self) -> bool[src]
Returns true if no flag is set
pub fn bits(self) -> T::Type[src]
Returns the underlying type value
pub fn intersects<B: Into<BitFlags<T>>>(self, other: B) -> bool[src]
Returns true if at least one flag is shared.
pub fn contains<B: Into<BitFlags<T>>>(self, other: B) -> bool[src]
Returns true iff all flags are contained.
pub fn not(self) -> Self[src]
Flips all flags
pub fn from_bits(bits: T::Type) -> Option<Self>[src]
Returns a BitFlags iff the bits value does not contain any illegal flags.
pub fn from_bits_truncate(bits: T::Type) -> Self[src]
Truncates flags that are illegal
pub fn toggle<B: Into<BitFlags<T>>>(&mut self, other: B)[src]
Toggles the matching bits
pub fn insert<B: Into<BitFlags<T>>>(&mut self, other: B)[src]
Inserts the flags into the BitFlag
pub fn remove<B: Into<BitFlags<T>>>(&mut self, other: B)[src]
Removes the matching flags